@@ -36,7 +36,7 @@ class QXmppServerPing : public QXmppServerExtension
 
 public:
     QStringList discoveryFeatures() const;
-    bool handleStanza(QXmppStream *stream, const QDomElement &element);
+    bool handleStanza(const QDomElement &element);
 };
 
 #endif
