@@ -51,6 +51,8 @@ private slots:
     void testBindResult();
     void testMessage();
     void testMessageFull();
+    void testMessageAttention();
+    void testMessageReceipt();
     void testMessageDelay();
     void testMessageLegacyDelay();
     void testNonSaslAuth();
@@ -58,6 +60,7 @@ private slots:
     void testPresenceFull();
     void testPresenceWithVCardUpdate();
     void testPresenceWithCapability();
+    void testPresenceWithMuc();
     void testSession();
     void testStreamFeatures();
     void testVCard();
@@ -67,6 +70,15 @@ private slots:
     void testEntityTimeResult();
 };
 
+class TestCodec : public QObject
+{
+    Q_OBJECT
+
+private slots:
+    void testTheoraDecoder();
+    void testTheoraEncoder();
+};
+
 class TestJingle : public QObject
 {
     Q_OBJECT
@@ -74,7 +86,8 @@ class TestJingle : public QObject
 private slots:
     void testSession();
     void testTerminate();
-    void testPayloadType();
+    void testAudioPayloadType();
+    void testVideoPayloadType();
     void testRinging();
 };
 
@@ -91,6 +104,24 @@ private slots:
     void testSubscriptions();
 };
 
+class TestRtp : public QObject
+{
+    Q_OBJECT
+
+private slots:
+    void testBad();
+    void testSimple();
+    void testWithCsrc();
+};
+
+class TestServer : public QObject
+{
+    Q_OBJECT
+
+private slots:
+    void testConnect();
+};
+
 class TestStun : public QObject
 {
     Q_OBJECT
